package com.tencent.qqmusiccommon.statistics.habo

import com.tencent.qqmusiccommon.statistics.VelocityStatistics
import com.tencent.qqmusiccommon.util.Util4Common
import com.tencent.qqmusicplayerprocess.statistics.StatisticsManagerConfig

/**
 * Copyright 2018 Tencent Inc. All Rights Reserved.
 * <p>
 * Detail: 哈勃上报
 * <p>
 * Author: glensun
 * Create on 2018/5/14.
 */

/**
 * 通过这个接口来上报数据到哈勃
 *
 * @param cid       标识这个统计的id,向后台申请,查询统计结果也根据这个id来查
 * @param code      上报的错误码,哈勃根据这个错误码进行统计
 * @param extraData 额外的上报数据,会写入哈勃数据库中,不会在habo上展示出来
 * @param random    设置采样率，越大采样比例越低，0表示不采样
 */
fun reportHabo(cid: Int, code: Int, extraData: String = "", random: Int = 0) {
    if (random == 0 || Util4Common.random(random)) {
        val statistics = VelocityStatistics(
                StatisticsManagerConfig.CMD_CGI_VELOCITY, cid.toLong(), code, extraData)
        statistics.setIsCgi(false)
        statistics.setIsWns(false)
        statistics.EndBuildXml()
    }
}

fun reportHabo(cid: Int, code: Int) {
    reportHabo(cid, code, "", 0)
}

fun reportHabo(cid: Int, code: Int, random: Int) {
    reportHabo(cid, code, "", random)
}

/**
 * 神奇的通道，可以上報客戶端統計數據到哈勃平台
 *
 * @param cid    CID客戶端指定，不重複就可以，需要向fazhangliu报备
 * @param code   错误码
 * @param random 抽样率,0表示不抽样，业务需要评估上报数据量，太大的话需要抽样。另外如果只是为了统计成功率，建议加大抽样
 */
fun reportMagicHabo(cid: Int, code: Long, random: Int, force: Boolean): Boolean {
    if (random == 0 || Util4Common.random(random)) {
        val statistics = VelocityStatistics(cid, code)
        statistics.setIsCgi(false)
        statistics.setIsWns(false)
        statistics.EndBuildXml(force)
        return true
    }
    return false
}

/**
 * 默认抽样1/5，默认非实时上报
 *
 * @param cid
 * @param code
 */
fun reportMagicHabo(cid: Int, code: Int) {
    reportMagicHabo(cid, code.toLong(), 5, false)
}