package com.tencent.qqmusictv.network.request

import com.tencent.qqmusiccommon.appconfig.QQMusicCGIConfig
import com.tencent.qqmusic.innovation.common.logging.MLog
import com.tencent.qqmusicplayerprocess.network.request.BaseCgiRequest
import com.tencent.qqmusictv.business.user.LocalUser
import com.tencent.qqmusictv.business.user.NewUser
import com.tencent.qqmusictv.common.model.BaseInfo
import com.tencent.qqmusictv.network.request.UnifiedCgiParameter.LOGINVIP_METHOD
import com.tencent.qqmusictv.network.request.UnifiedCgiParameter.LOGINVIP_MODULE
import com.tencent.qqmusictv.network.unifiedcgi.request.module.BaseModule.ModuleRequestItem
import com.tencent.qqmusictv.network.unifiedcgi.request.module.businessmodule.loginvip.LoginVipBody
import com.tencent.qqmusictv.network.unifiedcgi.response.loginvipresponse.LoginVipResponseRoot
import com.tencent.qqmusictv.utils.JsonUtil

/**
 * Copyright (C) 1998 - 2018 TENCENT Inc.All Rights Reserved.
 * @Title : trunkNew
 * @Description:拉取用户绿钻信息的请求
 * @Author : alexyjhan
 * @Data : 2018/4/20 09 : 33
 */

class LoginVipRequest(val user: LocalUser):BaseCgiRequest(){

    override fun initParams() {
        mUrl = QQMusicCGIConfig.getUnifiedUrl()
    }

    override fun checkRequest() {
        val track = ModuleRequestItem()
        track.setModule(LOGINVIP_MODULE)
        track.setMethod(LOGINVIP_METHOD)
        var body = LoginVipBody(track)
        when (user.userType) {
            NewUser.User_TYPE_QQ -> {
                body.comm.setQQ(user.currQQ)
                body.comm.setAuthst(user.authToken)
            }
            NewUser.User_TYPE_WX -> {
                body.comm.setQQ(user.wxMusicId)
                body.comm.setAuthst(user.authToken)
                body.comm.setWxopenid(user.wxOpenId)
                body.comm.setWxrefreshToken(user.wxRefreshToken)
            }
            else -> {
            }
        }
        val content = JsonUtil.toJsonString(body)
        if (null != content){
            setPostContent(content)
        }
    }

    override fun getDataObject(data: ByteArray): BaseInfo {
        MLog.d(TAG, "getDataObject : " + String(data))
        val info = JsonUtil.fromJsonBytes(LoginVipResponseRoot::class.java, data)
        return info
    }
}
