package com.tencent.qqmusictv.utils

import android.content.Context
import android.util.Log
import java.util.*

/**
 * author: glensun
 * detail: 耗时性能分析log
 * time  : 2016/6/24
 */
object PerformanceLogUtil {
    private const val TAG = "PerformanceLogUtil"

    private var processName = ""
    private var startTime = 0L
    private var lastTime = 0L

    private var tagPrinted = HashSet<String>()

    /* 是否位于主进程 */
    private var mMainProcess = false

    /**
     * 初始化
     */
    fun initializer(context: Context, initTime: Long) {
        mMainProcess = Util.inMainProcess(context)
        processName = Util.getProcessName(context)
        startTime = initTime
        lastTime = initTime
    }


    /**
     * 打印该tag增量时间和总时间
     */
    fun incrementLogTime(tag: String) {
        incrementLogTime(tag, false)
    }


    /**
     * 打印该tag增量时间和总时间
     *
     * @param once true-只输出一次; false-可输出多次
     */
    fun incrementLogTime(tag: String, once: Boolean) {
        incrementLogTime(tag, once, false)
    }

    /**
     * 打印该tag增量时间和总时间
     *
     * @param once            true-只输出一次; false-可输出多次
     * @param printAllProcess true-在所有进程中都输出log; false-只在主进程中输出log
     */
    fun incrementLogTime(tag: String, once: Boolean, printAllProcess: Boolean) {

        if (checkTAG(tag) && once) {
            /* 这个TAG已经输出过了，而且只允许输出一次，这里不再输出 */
            return
        }

        if (mMainProcess || printAllProcess) {
            val now = System.currentTimeMillis()
            if (lastTime == 0L) {
                lastTime = now
                startTime = now
            }

            printIncrementLog(tag, now - lastTime, now - startTime)
            lastTime = now
        }
    }

    /**
     * 打印log的实际行为
     */
    private fun printIncrementLog(msg: String, time1: Long, time2: Long) {
        Log.i(TAG, "$processName: [+$time1] $msg , total: $time2")
    }

    /**
     * 检查该tag是否已经输出过了
     *
     * @return true-已经输出过; false-还未输出过
     */
    private fun checkTAG(tag: String): Boolean {
        return if (tagPrinted.contains(tag)) {
            true
        } else {
            tagPrinted.add(tag)
            false
        }
    }
}
